#
# 5655-V64 (C) Copyright IBM Corp. 2009,2011                            
# All Rights Reserved. 
# Create three NamedEndPoints for the XDAgent in the dmgr/nodeagent ServerEntry of the specified node
# with the following endPointNames:
#   - XDAGENT_PORT, 
#   - OVERLAY_UDP_LISTENER_ADDRESS, 
#   - OVERLAY_TCP_LISTENER_ADDRESS.
#
# If a NamedEndPoint entry with the same name exists for the ServerEntry, its host and port attributes 
# will be replaced with "*" and the respective port number specified.
#

import java
import types

from sys import argv
from sys import exit

lineSeparator = java.lang.System.getProperty('line.separator')

#
# Stolen from some other random augmentation script, this makes a list from
# the sort of thing that AdminConfig.list() returns.
#
def convertToList(inlist):
     outlist=[]
     if (len(inlist)>0 and inlist[0]=='[' and inlist[len(inlist)-1]==']'):
        inlist = inlist[1:len(inlist)-1]
        clist = inlist.split(" ")
     else:
        clist = inlist.split(lineSeparator)
        
     for elem in clist:
        elem=elem.rstrip();
        if (len(elem)>0):
           outlist.append(elem)
     return outlist


def errorExit( exc, msg ):
	print msg
	raise exc, msg


##############################################
# Start of main() ........
##############################################


if len(argv) != 3: 
	errorExit( ValueError, "Wrong number of arguments supplied to script. Required arguments are: <XDAGENT_PORT> <OVERLAY_UDP_LISTENER_ADDRESS> <OVERLAY_TCP_LISTENER_ADDRESS>" )

agentPort = argv[0]
udpPort   = argv[1]
tcpPort   = argv[2]

print "Arguments passed in:", agentPort, udpPort, tcpPort 
print "Argument types:", type(agentPort), type(udpPort), type(tcpPort) 

endPointNamesToBeAdded = [ 	"XDAGENT_PORT",
							"OVERLAY_UDP_LISTENER_ADDRESS", 	
							"OVERLAY_TCP_LISTENER_ADDRESS"   ]

endPointMap	= { endPointNamesToBeAdded[0]:agentPort, endPointNamesToBeAdded[1]:udpPort, endPointNamesToBeAdded[2]:tcpPort }
   
# Make sure the three parameters passed in are all integer values
if ( not ( agentPort.isnumeric() and udpPort.isnumeric() and tcpPort.isnumeric() ) ):
	errorExit( ValueError, "Exiting because not all three arguments passed in are of type int." )
   
serverEntry = ""
serverName  = ""

nodeName = java.lang.System.getProperty('local.node');
if nodeName == None:
	errorExit( ValueError, "Name of node is not known. Aborted." )
else:
	print "Creating three NamedEndPoint elements in the 'dmgr' or 'nodeagent' ServerEntry of node", nodeName  
	print "Name and PortNumber of 'NamedEndPoint's to be added:"
	for k, v in endPointMap.items(): print "\t" + k, "=", v 

myNode = AdminConfig.getid( "/Node:" + nodeName + "/" )
srvEntries = convertToList( AdminConfig.list( "ServerEntry", myNode ) )

# Get the ServerEntry for server with the name 'dmgr' or 'nodeagent' for Node $nodeName .....
#
for srvEnt in srvEntries:
	srvName = AdminConfig.showAttribute( srvEnt, "serverName" )
	if srvName == "dmgr" or srvName == "nodeagent":
		serverName = srvName
		serverEntry = srvEnt
		break

if len( serverEntry ) == 0:
	errorExit( ValueError, "No ServerEntry with name 'dmgr' or 'nodeagent' found for node " + nodeName )

print "Found ServerEntry with name " + serverName + " for node " + nodeName

# Search and replace NamedEndPoint elements in the ServerEntry with the specified names
#
nepList = convertToList( AdminConfig.list( "NamedEndPoint", serverEntry ) )
for nep in nepList:
	epName = AdminConfig.showAttribute( nep, "endPointName" )
	if ( epName in endPointNamesToBeAdded ):
		print "Found NamedEndPoint element with name", epName, "in ServerEntry", serverEntry
		portNumber = endPointMap.get(epName)
		ep = AdminConfig.showAttribute( nep, "endPoint" )
		if ( ep == None ):
			print "..Creating endPoint attribute for NamedEndPoint element."
			ep 	= AdminConfig.create( "EndPoint", nep, [["host","*"],["port",portNumber]], "endPoint" )   
		else:
			print "..Replacing endPoint attribute of the NamedEndPoint element."
			oldHost = AdminConfig.showAttribute( ep, "host" )
			oldPort = AdminConfig.showAttribute( ep, "port" )
			print "..Old endPoint attribute: [[host:" +oldHost+ "],[port:" +oldPort+ "]]"
			AdminConfig.modify( ep, [["host","*"],["port",portNumber]] )   
		#
		# Remove name from the list
		endPointNamesToBeAdded.remove( epName )						
		print "Attributes of the updated NamedEndPoint element:", AdminConfig.showall( nep ) 
#   	
# Continue with the creation of the NamedEndPoint elements if there is any left in endPointNamesToBeAdded .............  	
#
for endPointName in endPointNamesToBeAdded:
	portNumber = endPointMap.get( endPointName )
	print "Creating a new NamedEndPoint element with endPointName " + endPointName + " and port " + portNumber
	# Create a new NamedEndPoint in the ServerEntry
	nep = AdminConfig.create( "NamedEndPoint", serverEntry, [["endPointName",endPointName]] ) 
	ep 	= AdminConfig.create( "EndPoint", nep, [["host","*"],["port",portNumber]], "endPoint" )   
	
AdminConfig.save()	
print "Done (Configuration Saved)."
