#!/bin/sh
#
# ================================================================ 
# PROPRIETARY-STATEMENT:                                           
# Licensed Material - Property of IBM                              
#                                                                  
# 5655-V64  (C) Copyright IBM Corp. 2009, 2011                            
# All Rights Reserved.                                             
# U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or 
# Disclosure restricted by GSA-ADP schedule contract with IBM Corp.
# Status = HEJO700                                                
# ================================================================ 
#
# create zos install image
# usage: ejosync.sh <install hfs location> <configuration hfs location
#

if [ -z $1 ]
then
   echo "Syntax: ejosync.sh <config hfs> <userid> <pswd>"   
   echo "where userid and password are optional"
   exit 8
fi

if [ ! -z $2 ]
then
   if [ -z $3 ]
   then
      echo "Syntax: ejosync.sh <config hfs> <userid> <pswd>"   
      echo "                             where userid and password are optional"
      exit 8 
   fi
fi

ConfigRoot=$1

if [ ! -e $ConfigRoot/profiles/default/bin/setupCmdLine.sh ]
then
   echo "The Configuration HFS location specified is invalid. $ConfigRoot/profiles/default/bin/setupCmdLine.sh does not exist!"
   exit 8
fi

. $ConfigRoot/profiles/default/bin/setupCmdLine.sh

f=$($JAVA_HOME/bin/java -classpath $ConfigRoot/lib/configParsers.jar com.ibm.ws.config390.parsers.Find $ConfigRoot/profiles/default/config/cells/$WAS_CELL serverindex.xml serverType=\"DEPLOYMENT_MANAGER\")
echo ""
echo ""
echo "extracting host from $f"
DmgrHost=$($JAVA_HOME/bin/java -classpath $ConfigRoot/lib/configParsers.jar com.ibm.ws.config390.parsers.ParseDmgrHostPort $f -host)
echo ""
echo "extracting port from $f"
DmgrPort=$($JAVA_HOME/bin/java -classpath $ConfigRoot/lib/configParsers.jar com.ibm.ws.config390.parsers.ParseDmgrHostPort $f -port)

echo ""
echo ""
echo "DMGR Host= $DmgrHost, DMGR Port= $DmgrPort"
echo ""
echo ""

if [ -z $DmgrHost ]
then
    echo "The DMGR Host was not extracted properly, please examine the error logs. Please note that you can sync this node by invoking the script $ConfigRoot/profiles/default/bin/syncNode.sh"
    exit 8
fi

if [ -z $DmgrPort ]
then
    echo "The DMGR Port was not extracted properly, please examine the error logs. Please note that you can sync this node by invoking the script $ConfigRoot/profiles/default/bin/syncNode.sh"
    exit 8
fi

if [ -z $2 ]
then
   echo Invoking the following command: $ConfigRoot/profiles/default/bin/syncNode.sh $DmgrHost $DmgrPort
   $ConfigRoot/profiles/default/bin/syncNode.sh $DmgrHost $DmgrPort
else 
	 echo Invoking the following command: $ConfigRoot/profiles/default/bin/syncNode.sh $DmgrHost $DmgrPort -user XXXXXX -password XXXXXX
	 $ConfigRoot/profiles/default/bin/syncNode.sh $DmgrHost $DmgrPort -user $2 -password $3
fi

rc=$?
if [ $rc -ne 0 ]
then
	echo "syncNode has failed. Please ensure that the Deployment Manager at host $DmgrHost and port $DmgrPort is running. "
fi